EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'AdminEdit_UpdateReleaseStatus',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates the status of a release.',
    /* Remarks_Text            */ NULL
GO

IF OBJECT_ID('[AdminEdit_UpdateReleaseStatus]') IS NOT NULL DROP PROCEDURE [AdminEdit_UpdateReleaseStatus]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [AdminEdit_UpdateReleaseStatus]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
    @ReleaseStatus_Name VARCHAR(9)
)
AS
BEGIN

    SET NOCOUNT ON

BEGIN TRY

    -- don't do anything if the status isn't changing
    IF EXISTS(SELECT * FROM [Releases]
               WHERE [Application_Id] = @Application_Id
                 AND [Release_Number] = @Release_Number
                 AND [ReleaseStatus_Name] = @ReleaseStatus_Name)
    BEGIN
        RETURN
    END
    

	BEGIN TRANSACTION

    IF (@ReleaseStatus_Name = 'Cancelled')
    BEGIN

        UPDATE [Releases]
           SET [ReleaseStatus_Name] = @ReleaseStatus_Name,
               [CancelledBy_User_Name] = [dbo].Session_GetUserName(),
               [CancelledOn_Date] = GETUTCDATE(),
               [CancelledReason_Text] = 'Canceled via Administrative Edit',
               [ModifiedOn_Date] = GETUTCDATE(),
               [ModifiedBy_User_Name] = dbo.Session_GetUserName()
         WHERE [Application_Id] = @Application_Id
           AND [Release_Number] = @Release_Number

    END
    ELSE
    BEGIN

        UPDATE [Releases]
           SET [ReleaseStatus_Name] = @ReleaseStatus_Name,
               [CancelledBy_User_Name] = NULL,
               [CancelledOn_Date] = NULL,
               [CancelledReason_Text] = NULL,
               [ModifiedOn_Date] = GETUTCDATE(),
               [ModifiedBy_User_Name] = [dbo].Session_GetUserName()
         WHERE [Application_Id] = @Application_Id
           AND [Release_Number] = @Release_Number

    END

    COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [AdminEdit_UpdateReleaseStatus] TO [BuildMasterUser_Role]
