﻿IF OBJECT_ID('[BuildTestResults_RecordTestResults]') IS NOT NULL DROP PROCEDURE [BuildTestResults_RecordTestResults]
GO

SET QUOTED_IDENTIFIER ON
GO

EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'BuildTestResults_RecordTestResults',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records multiple unit test results.'
GO

IF TYPE_ID('UnitTestResultEntry') IS NOT NULL DROP TYPE UnitTestResultEntry

CREATE TYPE UnitTestResultEntry AS TABLE
(
	[Group_Name] NVARCHAR(50) NOT NULL,
	[Test_Sequence] INT NOT NULL,
	[Test_Name] NVARCHAR(255) NOT NULL,
	[TestResult_Text] NVARCHAR(MAX) NOT NULL,
	[TestStarted_Date] DATETIME NOT NULL,
	[TestDuration_Milliseconds] BIGINT NOT NULL,
	[TestStatus_Code] CHAR(1) NOT NULL
)
GO

GRANT EXECUTE ON TYPE::[UnitTestResultEntry] TO [BuildMasterUser_Role]
GO

CREATE PROCEDURE [BuildTestResults_RecordTestResults]
(
	@Execution_Id INT,
	@UnitTestResults_Table dbo.UnitTestResultEntry READONLY
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [BuildTestResults]
	(
		[Execution_Id],
		[Group_Name],
		[Test_Sequence],
		[Test_Name],
		[TestResult_Text],
		[TestStarted_Date],
		[TestDuration_Milliseconds],
		[TestStatus_Code]
	)
	SELECT @Execution_Id,
	       [Group_Name],
		   [Test_Sequence],
		   [Test_Name],
		   [TestResult_Text],
		   [TestStarted_Date],
		   [TestDuration_Milliseconds],
		   [TestStatus_Code]
	  FROM @UnitTestResults_Table

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [BuildTestResults_RecordTestResults] TO [BuildMasterUser_Role]
