EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_PurgeBuildData',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Purges an entire build and all associated data from the system.'
GO

IF OBJECT_ID('[Builds_PurgeBuildData]') IS NOT NULL DROP PROCEDURE [Builds_PurgeBuildData]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_PurgeBuildData]
(
	@Build_Id INT
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Promotions TABLE ([Promotion_Id] INT NOT NULL)
	INSERT INTO @Promotions
	SELECT [Promotion_Id]
	  FROM [BuildPromotions]
	 WHERE [Build_Id] = @Build_Id

	DECLARE @Executions TABLE ([Execution_Id] INT NOT NULL)
	INSERT INTO @Executions ([Execution_Id])
	SELECT [Execution_Id]
	  FROM [PipelineStageTargetExecutions]
	 WHERE [Promotion_Id] IN (SELECT [Promotion_Id] FROM @Promotions)

	DELETE [ReleaseNotes]
	 WHERE [Build_Id] = @Build_Id

	DELETE [BuildArtifacts]
	 WHERE [Build_Id] = @Build_Id

    DELETE [BuildPromotionsScheduled]
	 WHERE [Build_Id] = @Build_Id

	DELETE [BuildTestResults]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildOutputs]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [ManualActionsInProgress]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [DatabaseChangeScriptExecutions]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [ScopedExecutionLogEntries]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [ScopedExecutionLogs]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [PipelineStageTargetExecutions]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildPromotions]
	 WHERE [Promotion_Id] IN (SELECT [Promotion_Id] FROM @Promotions)

	DELETE [Builds]
	 WHERE [Build_Id] = @Build_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END


GO

GRANT EXECUTE ON [Builds_PurgeBuildData] TO [BuildMasterUser_Role]
