EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ConfigurationFiles_UpdateConfigurationFileInstance',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates metadata for an existing configuration file instance.'
GO

IF OBJECT_ID('[ConfigurationFiles_UpdateConfigurationFileInstance]') IS NOT NULL DROP PROCEDURE [ConfigurationFiles_UpdateConfigurationFileInstance]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ConfigurationFiles_UpdateConfigurationFileInstance]
(
	@ConfigurationFile_Id INT,
	@Instance_Name VARCHAR(100),
    @Environment_Id INT,
	@Active_Indicator YNINDICATOR,
	@Template_Instance_Name VARCHAR(100),
	@TransformType_Code CHAR(1),
	@EditorType_Code CHAR(1)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Template_Instance_Name IS NOT NULL
	BEGIN
		IF (SELECT [Template_Indicator] FROM [ConfigurationFileInstances] WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id AND [Instance_Name] = @Template_Instance_Name) = 'N'
			RAISERROR('Specified template instance name must actually refer to a template instance.', 16, 1)
	END

	UPDATE [ConfigurationFileInstances]
	   SET [Environment_Id] = @Environment_Id,
	       [Active_Indicator] = @Active_Indicator,
		   [Template_Instance_Name] = @Template_Instance_Name,
		   [TransformType_Code] = @TransformType_Code,
		   [EditorType_Code] = @EditorType_Code
	 WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id
	   AND [Instance_Name] = @Instance_Name

	DECLARE @Application_Id INT
	    SET @Application_Id = (SELECT [Application_Id] 
	                             FROM [ConfigurationFiles]
 	                            WHERE [ConfigurationFile_Id] = @ConfigurationFile_Id)

	EXEC [Events_RaiseEvent] 'CFGMDI', @Application_Id, @ConfigurationFile_Id, @Instance_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ConfigurationFiles_UpdateConfigurationFileInstance] TO [BuildMasterUser_Role]
